# GiveAGame

![PyPI - License](https://img.shields.io/pypi/l/giveagame?label=License&style=plastic) ![PyPI - Wheel](https://img.shields.io/pypi/wheel/giveagame?style=plastic) ![PyPI-Version](https://img.shields.io/pypi/pyversions/giveagame?label=Python%20Version&style=plastic)

### Description

This is a simple game engine. 
[GitHub of Project](https://www.github.com/misha-network/giveagame)

### How to install?

1. *Open your* **terminal**.
2. *Check if* **Python** and **PIP** *are installed*.
3. *Finally run* command(**`pip install giveagame`**) in your **terminal**.

